@@ -56,10 +56,13 @@ struct c_block *cb_ptr;
     cb_ptr -> interpolator    = NULLINT;
     cb_ptr -> station_delay.ref = NULLFLOAT;
     cb_ptr -> station_delay.rem = NULLFLOAT;
-    cb_ptr -> pc_delay_l.ref = NULLFLOAT;
-    cb_ptr -> pc_delay_l.rem = NULLFLOAT;
-    cb_ptr -> pc_delay_r.ref = NULLFLOAT;
-    cb_ptr -> pc_delay_r.rem = NULLFLOAT;
+    cb_ptr -> pc_delay_l.ref  = NULLFLOAT;
+    cb_ptr -> pc_delay_l.rem  = NULLFLOAT;
+    cb_ptr -> pc_delay_r.ref  = NULLFLOAT;
+    cb_ptr -> pc_delay_r.rem  = NULLFLOAT;
+    cb_ptr -> weak_channel    = NULLFLOAT;
+    cb_ptr -> pc_amp_hcode    = NULLFLOAT;
+    cb_ptr -> fmatch_bw_pct   = NULLFLOAT;
 
     for (i=0; i<6; i++)
         cb_ptr -> adhoc_poly[i] = NULLFLOAT;
