@@ -159,9 +159,9 @@ struct type_pass *pass;
                 {
                 mbd_index = (mbd_index+1) % status.grid_points;
                 status.mbd = mbd_index;
-                                        // mean amplitude averaged over #pols, too
+                                        // mean amplitude
                 amps[mbd_index][dr_index] = c_mag (mb_delay[mbd_index]) 
-                                            / (status.total_ap_frac * pass->npols);
+                                            / status.total_ap_frac;
                 }  
             while (mbd_index != status.win_mb[1]);
             }
